
# THIS FILE IS GENERATED FROM SCIPY SETUP.PY
short_version = '1.6.2'
version = '1.6.2'
full_version = '1.6.2'
git_revision = 'f2ef65dc7f00672496d7de6154744fee55ef95e9'
release = True

if not release:
    version = full_version
